@@ -16,7 +16,7 @@ def die(message):
 
 class Inspector(object):
 
-    def __init__(self, container, no_name, pretty):
+    def __init__(self, container=None, no_name=None, pretty=None):
         self.container = container
         self.no_name = no_name
         self.output = ""
@@ -36,6 +36,9 @@ class Inspector(object):
             else:
                 die(str(e))
 
+    def set_facts(self, raw_json):
+        self.facts = loads(raw_json)
+
     def get_fact(self, path):
         parts = path.split(".")
         value = self.facts[0]
@@ -88,7 +91,7 @@ class Inspector(object):
                     host_ip = options[0]['HostIp']
                     host_port = options[0]['HostPort']
 
-                    if host_port != '0':
+                    if host_port != '0' and host_port != '':
                         host_port_part = f"{host_port}:"
 
                     if host_ip not in ['0.0.0.0', '']:
@@ -111,6 +114,11 @@ class Inspector(object):
 
         self.options += list(link_options)
 
+    def parse_pid(self):
+        mode = self.get_fact("HostConfig.PidMode")
+        if mode != "":
+            self.options.append("--pid %s" % mode)
+
     def parse_restart(self):
         restart = self.get_fact("HostConfig.RestartPolicy.Name")
         if not restart:
@@ -171,6 +179,16 @@ class Inspector(object):
         if runtime:
             self.options.append("--runtime=%s" % runtime)
 
+    def parse_memory(self):
+        memory = self.get_fact("HostConfig.Memory")
+        if memory:
+            self.options.append("--memory=\"%s\"" % memory)
+
+    def parse_memory_reservation(self):
+        memory_reservation = self.get_fact("HostConfig.MemoryReservation")
+        if memory_reservation:
+            self.options.append("--memory-reservation=\"%s\"" % memory_reservation)
+
     def format_cli(self):
         self.output = "docker run "
 
@@ -183,6 +201,7 @@ class Inspector(object):
         self.parse_hostname()
         self.parse_user()
         self.parse_macaddress()
+        self.parse_pid()
 
         self.multi_option("Config.Env", "env")
         self.multi_option("HostConfig.Binds", "volume")
@@ -207,6 +226,8 @@ class Inspector(object):
         self.parse_log()
         self.parse_extra_hosts()
         self.parse_runtime()
+        self.parse_memory()
+        self.parse_memory_reservation()
 
         stdout_attached = self.get_fact("Config.AttachStdout")
         if not stdout_attached:
